changeset 734:d87d85bf1a4d draft

Updated several tests.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Wed, 01 Jul 2015 13:02:13 +0200
parents 2de8cf02af41
children 5556f6317e9c
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 78 insertions(+), 73 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Fri Jun 12 13:44:39 2015 +0200
+++ b/ChangeLog	Wed Jul 01 13:02:13 2015 +0200
@@ -1,3 +1,8 @@
+2015-07-01  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated several tests.
+
 2015-06-12  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Fri Jun 12 13:44:39 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Jul 01 13:02:13 2015 +0200
@@ -8965,13 +8965,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -8980,13 +8980,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -8995,13 +8995,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -9010,13 +9010,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -9025,13 +9025,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -9040,13 +9040,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -9055,13 +9055,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -9070,13 +9070,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -9085,13 +9085,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -9100,13 +9100,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -9115,9 +9115,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.red);
+    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.red);
     }
 
     /**